Description Usage Arguments Details Value evalstatus Variable Specifications Author(s) References See Also Examples
Takes data for a single survey year and calculates site-specific design weights after accounting for frame error and nonresponse, while assuming missing-completely-at-random missingness.
1 | Adjwgt_FrameNR(dat, popn, evalstatus = "EvalStatus", wgt = "wgt")
|
dat |
A GRTS-design |
popn |
A text string identifying the type of membership of a site. Use
|
evalstatus |
A text string identifying the variable within |
wgt |
A text string identifying the variable within |
This routine is called by the sampling analysis Graphical User
Interface (GUI), i.e., function analysis.GUI, when its
‘Optional Weight Inputs’ ‘Adjust Weights?’ radio button is
set to ‘Yes.’ See analysis.GUI. Generally, this function is
not intended to be called directly by the user.
When the analysis.GUI routine requests adjustment of weights,
function Adjwgt_FrameNR modifies the included weights wgt in
dat for frame error and nonresponse. The methodology assumes any
missing sites are missing completely at random. Weighting adjustment is
appropriate for a single survey period (e.g. season or year) and does not
accommodate weighting for summary statistics of more than one survey
period.
A numeric vector adj.wt of length equal to the number-of-site
rows originally contained in dat.
evalstatus Variable SpecificationsEach row of dat represents a randomly selected site from the GRTS
sample draw. Generally, dat contains additional variables for data
collected during the survey. Essentially however, dat must contain a
field evalstatus that describes the sampling nature of all sampled
sites. An error is returned if the evalstatus variable is not
formatted to be one of the following four values:
"Target - Sampled" – The site is a member of the target
population and data were successfully collected.
"Target - Not Sampled" – The site is a member of the target
population, but data were not collected, e.g., due to innaccessibility,
landowner denial, etc.
"Not Evaluated" – The site was not assessed by observer
crews.
"Non-Target" – The site is not a member of the target
population.
Leigh Ann Starcevich (lstarcevish@west-inc.com)
Little, J. A. R., and Rubin, D. B. (2002). Statistical analysis with missing data, 2nd edition. John Wiley and Sons, Inc., New Jersey
Lessler, J. T. and Kalsbeek, W. D. (1992). Nonsampling errors in surveys. John Wiley and Sons, New York.
Oh, H. L. and Scheuren, F. J. (1983). Weighting adjustment for unit nonresponse. Pages 143-184 in W. G. Madow, I. Olkin, and D. B. Rubin, editors. Incomplete data and in sample surveys. (Vol. 2). Academic Press, New York.
Starcevich L. A., DiDonato G., McDonald T., Mitchell, J. (2016). A GRTS User's Manual for the SDrawNPS Package: A graphical user interface for Generalized Random Tessellation Stratified (GRTS) sampling and estimation. National Park Service, U.S. Department of the Interior. Natural Resource Report NPS/XXXX/NRR—20XX/XXX.
1 2 3 | # Adjust design weights for frame error
Adjwgt_FrameNR(dat=sampData,popn="Target - Surveyed",evalstatus="EvalStatus",wgt="wgt"))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.